/*
 * Copyright (C) 2005-2009 Makoto Sato. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package jp.objectfanatics.assertion.weaver.api.exception;

import jp.objectfanatics.assertion.weaver.api.exception.info.AnnotationInfo;
import jp.objectfanatics.assertion.weaver.api.exception.info.MethodInfo;
import jp.objectfanatics.assertion.weaver.api.exception.info.ParameterInfo;

//Checked 09.26.2009. Delete this line before release.
/**
 * Signals that parameter constraint annotation is overridden improperly.
 * 
 * @author Makoto Sato
 */
abstract public class IllegalParameterConstraintAnnotationOverridingException extends IllegalUseOfConstraintAnnotationException {
	
	/**
	 * Returns ancestor method information.
	 * 
	 * @return ancestor method information
	 */
	abstract public MethodInfo getAncestorMethod();
	
	/**
	 * Returns ancestor parameter information.
	 * 
	 * @return ancestor parameter information
	 */
	abstract public ParameterInfo getAncestorParameter();
	
	/**
	 * Returns target annotation information.
	 * 
	 * @return target annotation information
	 */
	abstract public AnnotationInfo getAncestorAnnotation();
	
	/**
	 * Returns target method information.
	 * 
	 * @return target method information
	 */
	abstract public MethodInfo getTargetMethod();
	
	/**
	 * Returns target parameter information.
	 * 
	 * @return target parameter information
	 */
	abstract public ParameterInfo getTargetParameter();
}
